from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking.PushNotifications
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.UI.Notifications
import win32more.Windows.Win32.System.WinRT
class IPushNotificationChannel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannel'
    _iid_ = Guid('{2b28102e-ef0b-4f39-9b8a-a3c194de7081}')
    @winrt_commethod(6)
    def get_Uri(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ExpirationTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(8)
    def Close(self) -> Void: ...
    @winrt_commethod(9)
    def add_PushNotificationReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.PushNotifications.PushNotificationChannel, win32more.Windows.Networking.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_PushNotificationReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
    PushNotificationReceived = event()
class IPushNotificationChannelManagerForUser(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser'
    _iid_ = Guid('{a4c45704-1182-42c7-8890-f563c4890dc4}')
    @winrt_commethod(6)
    def CreatePushNotificationChannelForApplicationAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(7)
    def CreatePushNotificationChannelForApplicationAsyncWithId(self, applicationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(8)
    def CreatePushNotificationChannelForSecondaryTileAsync(self, tileId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(9)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IPushNotificationChannelManagerForUser2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser2'
    _iid_ = Guid('{c38b066a-7cc1-4dac-87fd-be6e920414a4}')
    @winrt_commethod(6)
    def CreateRawPushNotificationChannelWithAlternateKeyForApplicationAsync(self, appServerKey: win32more.Windows.Storage.Streams.IBuffer, channelId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(7)
    def CreateRawPushNotificationChannelWithAlternateKeyForApplicationAsyncWithId(self, appServerKey: win32more.Windows.Storage.Streams.IBuffer, channelId: WinRT_String, appId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
class IPushNotificationChannelManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics'
    _iid_ = Guid('{8baf9b65-77a1-4588-bd19-861529a9dcf0}')
    @winrt_commethod(6)
    def CreatePushNotificationChannelForApplicationAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(7)
    def CreatePushNotificationChannelForApplicationAsyncWithId(self, applicationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_commethod(8)
    def CreatePushNotificationChannelForSecondaryTileAsync(self, tileId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
class IPushNotificationChannelManagerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics2'
    _iid_ = Guid('{b444a65d-a7e9-4b28-950e-f375a907f9df}')
    @winrt_commethod(6)
    def GetForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Networking.PushNotifications.PushNotificationChannelManagerForUser: ...
class IPushNotificationChannelManagerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics3'
    _iid_ = Guid('{4701fefe-0ede-4a3f-ae78-bfa471496925}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.Networking.PushNotifications.PushNotificationChannelManagerForUser: ...
class IPushNotificationChannelManagerStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics4'
    _iid_ = Guid('{bc540efb-7820-5a5b-9c01-b4757f774025}')
    @winrt_commethod(6)
    def add_ChannelsRevoked(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Networking.PushNotifications.PushNotificationChannelsRevokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ChannelsRevoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ChannelsRevoked = event()
class IPushNotificationChannelsRevokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationChannelsRevokedEventArgs'
    _iid_ = Guid('{20e1a24c-1a34-5beb-aae2-40c232c8c140}')
class IPushNotificationReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs'
    _iid_ = Guid('{d1065e0c-36cd-484c-b935-0a99b753cf00}')
    @winrt_commethod(6)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_NotificationType(self) -> win32more.Windows.Networking.PushNotifications.PushNotificationType: ...
    @winrt_commethod(9)
    def get_ToastNotification(self) -> win32more.Windows.UI.Notifications.ToastNotification: ...
    @winrt_commethod(10)
    def get_TileNotification(self) -> win32more.Windows.UI.Notifications.TileNotification: ...
    @winrt_commethod(11)
    def get_BadgeNotification(self) -> win32more.Windows.UI.Notifications.BadgeNotification: ...
    @winrt_commethod(12)
    def get_RawNotification(self) -> win32more.Windows.Networking.PushNotifications.RawNotification: ...
    BadgeNotification = property(get_BadgeNotification, None)
    Cancel = property(get_Cancel, put_Cancel)
    NotificationType = property(get_NotificationType, None)
    RawNotification = property(get_RawNotification, None)
    TileNotification = property(get_TileNotification, None)
    ToastNotification = property(get_ToastNotification, None)
class IRawNotification(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IRawNotification'
    _iid_ = Guid('{1a227281-3b79-42ac-9963-22ab00d4f0b7}')
    @winrt_commethod(6)
    def get_Content(self) -> WinRT_String: ...
    Content = property(get_Content, None)
class IRawNotification2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IRawNotification2'
    _iid_ = Guid('{e6d0cf19-0c6f-4cdd-9424-eec5be014d26}')
    @winrt_commethod(6)
    def get_Headers(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_commethod(7)
    def get_ChannelId(self) -> WinRT_String: ...
    ChannelId = property(get_ChannelId, None)
    Headers = property(get_Headers, None)
class IRawNotification3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.IRawNotification3'
    _iid_ = Guid('{62737dde-8a73-424c-ab44-5635f40a96e5}')
    @winrt_commethod(6)
    def get_ContentBytes(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    ContentBytes = property(get_ContentBytes, None)
class PushNotificationChannel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel
    _classid_ = 'Windows.Networking.PushNotifications.PushNotificationChannel'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExpirationTime(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel) -> Void: ...
    @winrt_mixinmethod
    def add_PushNotificationReceived(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.PushNotifications.PushNotificationChannel, win32more.Windows.Networking.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PushNotificationReceived(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannel, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
    PushNotificationReceived = event()
class PushNotificationChannelManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.PushNotifications.PushNotificationChannelManager'
    @winrt_classmethod
    def add_ChannelsRevoked(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics4, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Networking.PushNotifications.PushNotificationChannelsRevokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_ChannelsRevoked(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics3) -> win32more.Windows.Networking.PushNotifications.PushNotificationChannelManagerForUser: ...
    @winrt_classmethod
    def GetForUser(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics2, user: win32more.Windows.System.User) -> win32more.Windows.Networking.PushNotifications.PushNotificationChannelManagerForUser: ...
    @winrt_classmethod
    def CreatePushNotificationChannelForApplicationAsync(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_classmethod
    def CreatePushNotificationChannelForApplicationAsyncWithId(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics, applicationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_classmethod
    def CreatePushNotificationChannelForSecondaryTileAsync(cls: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerStatics, tileId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
class PushNotificationChannelManagerForUser(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser
    _classid_ = 'Windows.Networking.PushNotifications.PushNotificationChannelManagerForUser'
    @winrt_mixinmethod
    def CreatePushNotificationChannelForApplicationAsync(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_mixinmethod
    def CreatePushNotificationChannelForApplicationAsyncWithId(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser, applicationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_mixinmethod
    def CreatePushNotificationChannelForSecondaryTileAsync(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser, tileId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def CreateRawPushNotificationChannelWithAlternateKeyForApplicationAsync(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser2, appServerKey: win32more.Windows.Storage.Streams.IBuffer, channelId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    @winrt_mixinmethod
    def CreateRawPushNotificationChannelWithAlternateKeyForApplicationAsyncWithId(self: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelManagerForUser2, appServerKey: win32more.Windows.Storage.Streams.IBuffer, channelId: WinRT_String, appId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.PushNotifications.PushNotificationChannel]: ...
    User = property(get_User, None)
class PushNotificationChannelsRevokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.PushNotifications.IPushNotificationChannelsRevokedEventArgs
    _classid_ = 'Windows.Networking.PushNotifications.PushNotificationChannelsRevokedEventArgs'
class PushNotificationReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs
    _classid_ = 'Windows.Networking.PushNotifications.PushNotificationReceivedEventArgs'
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_NotificationType(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.Networking.PushNotifications.PushNotificationType: ...
    @winrt_mixinmethod
    def get_ToastNotification(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.UI.Notifications.ToastNotification: ...
    @winrt_mixinmethod
    def get_TileNotification(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.UI.Notifications.TileNotification: ...
    @winrt_mixinmethod
    def get_BadgeNotification(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.UI.Notifications.BadgeNotification: ...
    @winrt_mixinmethod
    def get_RawNotification(self: win32more.Windows.Networking.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.Networking.PushNotifications.RawNotification: ...
    BadgeNotification = property(get_BadgeNotification, None)
    Cancel = property(get_Cancel, put_Cancel)
    NotificationType = property(get_NotificationType, None)
    RawNotification = property(get_RawNotification, None)
    TileNotification = property(get_TileNotification, None)
    ToastNotification = property(get_ToastNotification, None)
class PushNotificationType(Enum, Int32):
    Toast = 0
    Tile = 1
    Badge = 2
    Raw = 3
    TileFlyout = 4
class RawNotification(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.PushNotifications.IRawNotification
    _classid_ = 'Windows.Networking.PushNotifications.RawNotification'
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.Networking.PushNotifications.IRawNotification) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Headers(self: win32more.Windows.Networking.PushNotifications.IRawNotification2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def get_ChannelId(self: win32more.Windows.Networking.PushNotifications.IRawNotification2) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContentBytes(self: win32more.Windows.Networking.PushNotifications.IRawNotification3) -> win32more.Windows.Storage.Streams.IBuffer: ...
    ChannelId = property(get_ChannelId, None)
    Content = property(get_Content, None)
    ContentBytes = property(get_ContentBytes, None)
    Headers = property(get_Headers, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.NetShell
NETSH_ERROR_BASE: UInt32 = 15000
ERROR_NO_ENTRIES: UInt32 = 15000
ERROR_INVALID_SYNTAX: UInt32 = 15001
ERROR_PROTOCOL_NOT_IN_TRANSPORT: UInt32 = 15002
ERROR_NO_CHANGE: UInt32 = 15003
ERROR_CMD_NOT_FOUND: UInt32 = 15004
ERROR_ENTRY_PT_NOT_FOUND: UInt32 = 15005
ERROR_DLL_LOAD_FAILED: UInt32 = 15006
ERROR_INIT_DISPLAY: UInt32 = 15007
ERROR_TAG_ALREADY_PRESENT: UInt32 = 15008
ERROR_INVALID_OPTION_TAG: UInt32 = 15009
ERROR_NO_TAG: UInt32 = 15010
ERROR_MISSING_OPTION: UInt32 = 15011
ERROR_TRANSPORT_NOT_PRESENT: UInt32 = 15012
ERROR_SHOW_USAGE: UInt32 = 15013
ERROR_INVALID_OPTION_VALUE: UInt32 = 15014
ERROR_OKAY: UInt32 = 15015
ERROR_CONTINUE_IN_PARENT_CONTEXT: UInt32 = 15016
ERROR_SUPPRESS_OUTPUT: UInt32 = 15017
ERROR_HELPER_ALREADY_REGISTERED: UInt32 = 15018
ERROR_CONTEXT_ALREADY_REGISTERED: UInt32 = 15019
ERROR_PARSING_FAILURE: UInt32 = 15020
NETSH_ERROR_END: UInt32 = 15019
NS_GET_EVENT_IDS_FN_NAME: String = 'GetEventIds'
MAX_NAME_LEN: UInt32 = 48
NETSH_VERSION_50: UInt32 = 20480
NETSH_ARG_DELIMITER: String = '='
NETSH_CMD_DELIMITER: String = ' '
NETSH_MAX_TOKEN_LENGTH: UInt32 = 64
NETSH_MAX_CMD_TOKEN_LENGTH: UInt32 = 128
DEFAULT_CONTEXT_PRIORITY: UInt32 = 100
GET_RESOURCE_STRING_FN_NAME: String = 'GetResourceString'
@winfunctype('NETSH.dll')
def MatchEnumTag(hModule: win32more.Windows.Win32.Foundation.HANDLE, pwcArg: win32more.Windows.Win32.Foundation.PWSTR, dwNumArg: UInt32, pEnumTable: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.TOKEN_VALUE), pdwValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('NETSH.dll')
def MatchToken(pwszUserToken: win32more.Windows.Win32.Foundation.PWSTR, pwszCmdToken: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('NETSH.dll')
def PreprocessCommand(hModule: win32more.Windows.Win32.Foundation.HANDLE, ppwcArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwCurrentIndex: UInt32, dwArgCount: UInt32, pttTags: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.TAG_TYPE), dwTagCount: UInt32, dwMinArgs: UInt32, dwMaxArgs: UInt32, pdwTagType: POINTER(UInt32)) -> UInt32: ...
@cfunctype('NETSH.dll', variadic=True)
def PrintError(hModule: win32more.Windows.Win32.Foundation.HANDLE, dwErrId: UInt32, *__arglist) -> UInt32: ...
@cfunctype('NETSH.dll', variadic=True)
def PrintMessageFromModule(hModule: win32more.Windows.Win32.Foundation.HANDLE, dwMsgId: UInt32, *__arglist) -> UInt32: ...
@cfunctype('NETSH.dll', variadic=True)
def PrintMessage(pwszFormat: win32more.Windows.Win32.Foundation.PWSTR, *__arglist) -> UInt32: ...
@winfunctype('NETSH.dll')
def RegisterContext(pChildContext: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.NS_CONTEXT_ATTRIBUTES)) -> UInt32: ...
@winfunctype('NETSH.dll')
def RegisterHelper(pguidParentContext: POINTER(Guid), pfnRegisterSubContext: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.NS_HELPER_ATTRIBUTES)) -> UInt32: ...
class CMD_ENTRY(Structure):
    pwszCmdToken: win32more.Windows.Win32.Foundation.PWSTR
    pfnCmdHandler: win32more.Windows.Win32.NetworkManagement.NetShell.PFN_HANDLE_CMD
    dwShortCmdHelpToken: UInt32
    dwCmdHlpToken: UInt32
    dwFlags: UInt32
    pOsVersionCheck: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_OSVERSIONCHECK
    pfnCustomHelpFn: win32more.Windows.Win32.NetworkManagement.NetShell.PFN_CUSTOM_HELP
class CMD_GROUP_ENTRY(Structure):
    pwszCmdGroupToken: win32more.Windows.Win32.Foundation.PWSTR
    dwShortCmdHelpToken: UInt32
    ulCmdGroupSize: UInt32
    dwFlags: UInt32
    pCmdGroup: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.CMD_ENTRY)
    pOsVersionCheck: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_OSVERSIONCHECK
NS_CMD_FLAGS = Int32
CMD_FLAG_PRIVATE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 1
CMD_FLAG_INTERACTIVE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 2
CMD_FLAG_LOCAL: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 8
CMD_FLAG_ONLINE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 16
CMD_FLAG_HIDDEN: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 32
CMD_FLAG_LIMIT_MASK: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = 65535
CMD_FLAG_PRIORITY: win32more.Windows.Win32.NetworkManagement.NetShell.NS_CMD_FLAGS = -2147483648
class NS_CONTEXT_ATTRIBUTES(Structure):
    Anonymous: _Anonymous_e__Union
    pwszContext: win32more.Windows.Win32.Foundation.PWSTR
    guidHelper: Guid
    dwFlags: UInt32
    ulPriority: UInt32
    ulNumTopCmds: UInt32
    pTopCmds: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.CMD_ENTRY)
    ulNumGroups: UInt32
    pCmdGroups: POINTER(win32more.Windows.Win32.NetworkManagement.NetShell.CMD_GROUP_ENTRY)
    pfnCommitFn: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_CONTEXT_COMMIT_FN
    pfnDumpFn: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_CONTEXT_DUMP_FN
    pfnConnectFn: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_CONTEXT_CONNECT_FN
    pReserved: VoidPtr
    pfnOsVersionCheck: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_OSVERSIONCHECK
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        _ullAlign: UInt64
        class _Anonymous_e__Struct(Structure):
            dwVersion: UInt32
            dwReserved: UInt32
NS_EVENTS = Int32
NS_EVENT_LOOP: win32more.Windows.Win32.NetworkManagement.NetShell.NS_EVENTS = 65536
NS_EVENT_LAST_N: win32more.Windows.Win32.NetworkManagement.NetShell.NS_EVENTS = 1
NS_EVENT_LAST_SECS: win32more.Windows.Win32.NetworkManagement.NetShell.NS_EVENTS = 2
NS_EVENT_FROM_N: win32more.Windows.Win32.NetworkManagement.NetShell.NS_EVENTS = 4
NS_EVENT_FROM_START: win32more.Windows.Win32.NetworkManagement.NetShell.NS_EVENTS = 8
class NS_HELPER_ATTRIBUTES(Structure):
    Anonymous: _Anonymous_e__Union
    guidHelper: Guid
    pfnStart: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_HELPER_START_FN
    pfnStop: win32more.Windows.Win32.NetworkManagement.NetShell.PNS_HELPER_STOP_FN
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        _ullAlign: UInt64
        class _Anonymous_e__Struct(Structure):
            dwVersion: UInt32
            dwReserved: UInt32
NS_MODE_CHANGE = Int32
NETSH_COMMIT: win32more.Windows.Win32.NetworkManagement.NetShell.NS_MODE_CHANGE = 0
NETSH_UNCOMMIT: win32more.Windows.Win32.NetworkManagement.NetShell.NS_MODE_CHANGE = 1
NETSH_FLUSH: win32more.Windows.Win32.NetworkManagement.NetShell.NS_MODE_CHANGE = 2
NETSH_COMMIT_STATE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_MODE_CHANGE = 3
NETSH_SAVE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_MODE_CHANGE = 4
NS_REQS = Int32
NS_REQ_ZERO: win32more.Windows.Win32.NetworkManagement.NetShell.NS_REQS = 0
NS_REQ_PRESENT: win32more.Windows.Win32.NetworkManagement.NetShell.NS_REQS = 1
NS_REQ_ALLOW_MULTIPLE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_REQS = 2
NS_REQ_ONE_OR_MORE: win32more.Windows.Win32.NetworkManagement.NetShell.NS_REQS = 3
@winfunctype_pointer
def PFN_CUSTOM_HELP(hModule: win32more.Windows.Win32.Foundation.HANDLE, pwszCmdToken: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
@winfunctype_pointer
def PFN_HANDLE_CMD(pwszMachine: win32more.Windows.Win32.Foundation.PWSTR, ppwcArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwCurrentIndex: UInt32, dwArgCount: UInt32, dwFlags: UInt32, pvData: VoidPtr, pbDone: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PGET_RESOURCE_STRING_FN(dwMsgID: UInt32, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nBufferMax: UInt32) -> UInt32: ...
@winfunctype_pointer
def PNS_CONTEXT_COMMIT_FN(dwAction: UInt32) -> UInt32: ...
@winfunctype_pointer
def PNS_CONTEXT_CONNECT_FN(pwszMachine: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PNS_CONTEXT_DUMP_FN(pwszRouter: win32more.Windows.Win32.Foundation.PWSTR, ppwcArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwArgCount: UInt32, pvData: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PNS_DLL_INIT_FN(dwNetshVersion: UInt32, pReserved: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PNS_DLL_STOP_FN(dwReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def PNS_HELPER_START_FN(pguidParent: POINTER(Guid), dwVersion: UInt32) -> UInt32: ...
@winfunctype_pointer
def PNS_HELPER_STOP_FN(dwReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def PNS_OSVERSIONCHECK(CIMOSType: UInt32, CIMOSProductSuite: UInt32, CIMOSVersion: win32more.Windows.Win32.Foundation.PWSTR, CIMOSBuildNumber: win32more.Windows.Win32.Foundation.PWSTR, CIMServicePackMajorVersion: win32more.Windows.Win32.Foundation.PWSTR, CIMServicePackMinorVersion: win32more.Windows.Win32.Foundation.PWSTR, uiReserved: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class TAG_TYPE(Structure):
    pwszTag: win32more.Windows.Win32.Foundation.PWSTR
    dwRequired: UInt32
    bPresent: win32more.Windows.Win32.Foundation.BOOL
class TOKEN_VALUE(Structure):
    pwszToken: win32more.Windows.Win32.Foundation.PWSTR
    dwValue: UInt32


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.ConfigurationSnapin
import win32more.Windows.Win32.System.Com
cNodetypeSceTemplateServices: Guid = Guid('{24a7f717-1f0c-11d1-affb-00c04fb984f9}')
cNodetypeSceAnalysisServices: Guid = Guid('{678050c7-1ff8-11d1-affb-00c04fb984f9}')
cNodetypeSceEventLog: Guid = Guid('{2ce06698-4bf3-11d1-8c30-00c04fb984f9}')
SCESTATUS_SUCCESS: Int32 = 0
SCESTATUS_INVALID_PARAMETER: Int32 = 1
SCESTATUS_RECORD_NOT_FOUND: Int32 = 2
SCESTATUS_INVALID_DATA: Int32 = 3
SCESTATUS_OBJECT_EXIST: Int32 = 4
SCESTATUS_BUFFER_TOO_SMALL: Int32 = 5
SCESTATUS_PROFILE_NOT_FOUND: Int32 = 6
SCESTATUS_BAD_FORMAT: Int32 = 7
SCESTATUS_NOT_ENOUGH_RESOURCE: Int32 = 8
SCESTATUS_ACCESS_DENIED: Int32 = 9
SCESTATUS_CANT_DELETE: Int32 = 10
SCESTATUS_PREFIX_OVERFLOW: Int32 = 11
SCESTATUS_OTHER_ERROR: Int32 = 12
SCESTATUS_ALREADY_RUNNING: Int32 = 13
SCESTATUS_SERVICE_NOT_SUPPORT: Int32 = 14
SCESTATUS_MOD_NOT_FOUND: Int32 = 15
SCESTATUS_EXCEPTION_IN_SERVER: Int32 = 16
SCESTATUS_NO_TEMPLATE_GIVEN: Int32 = 17
SCESTATUS_NO_MAPPING: Int32 = 18
SCESTATUS_TRUST_FAIL: Int32 = 19
SCE_ROOT_PATH: String = 'Software\\Microsoft\\Windows NT\\CurrentVersion\\SeCEdit'
SCESVC_ENUMERATION_MAX: Int32 = 100
struuidNodetypeSceTemplateServices: String = '{24a7f717-1f0c-11d1-affb-00c04fb984f9}'
lstruuidNodetypeSceTemplateServices: String = '{24a7f717-1f0c-11d1-affb-00c04fb984f9}'
struuidNodetypeSceAnalysisServices: String = '{678050c7-1ff8-11d1-affb-00c04fb984f9}'
lstruuidNodetypeSceAnalysisServices: String = '{678050c7-1ff8-11d1-affb-00c04fb984f9}'
struuidNodetypeSceEventLog: String = '{2ce06698-4bf3-11d1-8c30-00c04fb984f9}'
lstruuidNodetypeSceEventLog: String = '{2ce06698-4bf3-11d1-8c30-00c04fb984f9}'
CCF_SCESVC_ATTACHMENT: String = 'CCF_SCESVC_ATTACHMENT'
CCF_SCESVC_ATTACHMENT_DATA: String = 'CCF_SCESVC_ATTACHMENT_DATA'
class ISceSvcAttachmentData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{17c35fde-200d-11d1-affb-00c04fb984f9}')
    @commethod(3)
    def GetData(self, scesvcHandle: VoidPtr, sceType: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE, ppvData: POINTER(VoidPtr), psceEnumHandle: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Initialize(self, lpServiceName: POINTER(SByte), lpTemplateName: POINTER(SByte), lpSceSvcPersistInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.ISceSvcAttachmentPersistInfo, pscesvcHandle: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FreeBuffer(self, pvData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CloseHandle(self, scesvcHandle: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISceSvcAttachmentPersistInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6d90e0d0-200d-11d1-affb-00c04fb984f9}')
    @commethod(3)
    def Save(self, lpTemplateName: POINTER(SByte), scesvcHandle: POINTER(VoidPtr), ppvData: POINTER(VoidPtr), pbOverwriteAll: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsDirty(self, lpTemplateName: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FreeBuffer(self, pvData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFSCE_FREE_INFO(pvServiceInfo: VoidPtr) -> UInt32: ...
@cfunctype_pointer
def PFSCE_LOG_INFO(ErrLevel: win32more.Windows.Win32.Security.ConfigurationSnapin.SCE_LOG_ERR_LEVEL, Win32rc: UInt32, pErrFmt: POINTER(SByte)) -> UInt32: ...
@winfunctype_pointer
def PFSCE_QUERY_INFO(sceHandle: VoidPtr, sceType: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE, lpPrefix: POINTER(SByte), bExact: win32more.Windows.Win32.Foundation.BOOL, ppvInfo: POINTER(VoidPtr), psceEnumHandle: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PFSCE_SET_INFO(sceHandle: VoidPtr, sceType: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE, lpPrefix: POINTER(SByte), bExact: win32more.Windows.Win32.Foundation.BOOL, pvInfo: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PF_ConfigAnalyzeService(pSceCbInfo: POINTER(win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_CALLBACK_INFO)) -> UInt32: ...
@winfunctype_pointer
def PF_UpdateService(pSceCbInfo: POINTER(win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_CALLBACK_INFO), ServiceInfo: POINTER(win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_CONFIGURATION_INFO)) -> UInt32: ...
class SCESVC_ANALYSIS_INFO(Structure):
    Count: UInt32
    Lines: POINTER(win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_ANALYSIS_LINE)
class SCESVC_ANALYSIS_LINE(Structure):
    Key: POINTER(SByte)
    Value: POINTER(Byte)
    ValueLen: UInt32
class SCESVC_CALLBACK_INFO(Structure):
    sceHandle: VoidPtr
    pfQueryInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.PFSCE_QUERY_INFO
    pfSetInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.PFSCE_SET_INFO
    pfFreeInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.PFSCE_FREE_INFO
    pfLogInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.PFSCE_LOG_INFO
class SCESVC_CONFIGURATION_INFO(Structure):
    Count: UInt32
    Lines: POINTER(win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_CONFIGURATION_LINE)
class SCESVC_CONFIGURATION_LINE(Structure):
    Key: POINTER(SByte)
    Value: POINTER(SByte)
    ValueLen: UInt32
SCESVC_INFO_TYPE = Int32
SceSvcConfigurationInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE = 0
SceSvcMergedPolicyInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE = 1
SceSvcAnalysisInfo: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE = 2
SceSvcInternalUse: win32more.Windows.Win32.Security.ConfigurationSnapin.SCESVC_INFO_TYPE = 3
SCE_LOG_ERR_LEVEL = Int32
SCE_LOG_LEVEL_ALWAYS: win32more.Windows.Win32.Security.ConfigurationSnapin.SCE_LOG_ERR_LEVEL = 0
SCE_LOG_LEVEL_ERROR: win32more.Windows.Win32.Security.ConfigurationSnapin.SCE_LOG_ERR_LEVEL = 1
SCE_LOG_LEVEL_DETAIL: win32more.Windows.Win32.Security.ConfigurationSnapin.SCE_LOG_ERR_LEVEL = 2
SCE_LOG_LEVEL_DEBUG: win32more.Windows.Win32.Security.ConfigurationSnapin.SCE_LOG_ERR_LEVEL = 3


make_ready(__name__)
